@@ -8,9 +8,9 @@ from commitizen.cz import ConventionalCommitsCz
 class ConventionalJiraCz(ConventionalCommitsCz):
     def schema_pattern(self) -> Pattern[AnyStr]:
         conf = config.read_cfg()
-        jira_prefix = conf.settings.get('jira_prefix', default=None)
-        jira_issues_required = conf.settings.get('jira_issues_required', default=False)
-        jira_no_ticket_key = conf.settings.get('jira_no_ticket_key', default=None)
+        jira_prefix = conf.settings.get('jira_prefix', None)
+        jira_issues_required = conf.settings.get('jira_issues_required', False)
+        jira_no_ticket_key = conf.settings.get('jira_no_ticket_key', None)
         if jira_prefix:
             if jira_no_ticket_key:
                 issue_pattern = f"{jira_prefix}-(?:\d+(?:,{jira_prefix}-(?:\d+))*|{jira_no_ticket_key})"
